clear all

GLOBALS

% ===============================================================================
% User changes allowed here!
% --------------------------
  BALANCEBUDGET   = 0;   % balanced budget policy?
  OPTIM_BAL       = 0;   % this country optimizes, others balance the budget?
  BAL_OPTIM       = 0;   % this country balances, others optimize the budget?
  AUTARKY         = 0;   % country in autarky?
  CONSTANTR       = 0;   % constant factor prices?
  VARYELAST       = 0;   % high lab. supply elast. if positive, low if negative
  VARYRISK        = 0;   % low risk aversion (mu=1) if negative. DO NOT COMBINE WITH VARYELAST!!!
  INITIATESS      = 0;   % update solution for initial steady state?
  EU              = 0;
  GRAPHS          = 1;
% ===============================================================================


addpath utilfcn


% Preferences
mu       = 2;
muI      = mu;



fileext = '';
if BALANCEBUDGET
  fileext = '_BB';
elseif OPTIM_BAL
  fileext = '_OB';
elseif BAL_OPTIM
  fileext = '_BO';
else
  fileext = '_OP';
end

if AUTARKY
  fileext = [fileext '_AU'];
elseif CONSTANTR
  fileext = [fileext '_CR'];
elseif EU
  fileext = [fileext '_EU'];
end

if VARYELAST < 0
  fileext = [fileext '_low'];
  INITIALSSFILE = 'results\initial_ss_low';
  gmma          = 1/.1;
  zeta          = 16500;
elseif VARYELAST >0
  fileext = [fileext '_hgh'];
  INITIALSSFILE = 'results\initial_ss_hgh';
  gmma          = 1/.5;
  zeta          = 10.03;
elseif VARYRISK < 0
  fileext       = [fileext '_mu1'];
  INITIALSSFILE = 'results\initial_ss_mu1';
  gmma          = 1/.3;
  mu            = 1.0001;
  muI           = mu;
  zeta          = 31.7;
else
  INITIALSSFILE = 'results\initial_ss';
  gmma          = 1/.3;
  zeta          = 30;
end


T        = 149;         % # of years (T=150 in solve_r)
T0       = 50;          % # of years with demographics


% Production, prices, population and initial conditions
delta    = .1;
theta    = .36;
tauPI    = .4;


warning on


if INITIATESS
  T=T+1;
  prints('Solving for initial steady states...',0);
  solve_initial_ss
  T=T-1;
end


if EU
  COUNTRIES = [1 2 4 5 6 7 8 9 10 11 12];
else
  COUNTRIES = 1:15;
end


% =======================================================================
% Solve for interest rate path
% =======================================================================

prints('Solving for world interest rate path...',0);

load(INITIALSSFILE,'bta')
x = (1/bta-1)*ones(T,1);
if exist('results\x.mat'), load results\x; end
minR = .02*ones(T,1);
maxR = .035*ones(T,1);

if GRAPHS
  figure, subplot(2,2,3), a=[1 150 minR(1) maxR(1)]; axis(a);
  title('Rpath')
end


if AUTARKY

    n = 0;
    filename = ['results\res' fileext '.mat'];
    if exist(filename)
        load(filename);
        n = length(res);
    end
    for i = n+1:15; 
        res(i).x     = []; 
        res(i).Rpath = (1/bta-1)*ones(T,1);
    end
    save(filename,'res');

    for cty = 1:15
        x = res(cty).Rpath(1:T);

        fprintf('Solving country # %2d ... ',cty);
        x = solve_transition(x,cty);
        fprintf('Solved. Diff = %12.8f\n',sum(x.^2));
    
    end


elseif CONSTANTR

    x = (1/bta-1)*ones(T,1);
    solve_transition(x,1:15);


elseif OPTIM_BAL

    filename2 = ['results\res_BB' fileext(4:end) '.mat'];       % Use R from BB solution
    load(filename2)
    x = res(1).Rpath(1:T);
    
    solve_transition(x,1:15);


elseif BAL_OPTIM

    filename2 = ['results\res_OP' fileext(4:end) '.mat'];
    load(filename2)
    x = res(1).Rpath(1:T);
  
    BALANCEBUDGET = 1;  
    solve_transition(x,COUNTRIES);


else

    filename = ['results\res' fileext '.mat'];
    if exist(filename,'file')
        load(filename)
        x = res(1).Rpath(1:T);
    end

 
    JacPat  = diag(ones(T,1));
    for i=1:0
      JacPat = JacPat + diag(ones(T-i,1),-i) + diag(ones(T-i,1),i);
    end

    options = optimset('Diagnostics','off','Display','iter','MaxIter',5,...
              'TolFun',1e-7,'LargeScale','on','Jacobian','off',...
              'JacobPattern',JacPat,'LevenbergMarquardt','off',...
              'TolX',1e-8);

    for i=1:1
      [x, resnorm, resid, rc, output, lambda, Jac] = lsqnonlin('solve_transition',x,minR,maxR,options,COUNTRIES);
      save results\x x;
    end

end

