% Welfare analysis

clear all

GLOBALS

T       = 150;


% Preferences
mu       = 2;
muI      = mu;
gmma     = 1/.3;
zeta     = 30;

load results\initial_ss

load results\res_op;       res_op       = res;
load results\res_bo;       res_bo       = res;
load results\res_op_low;   res_op_low   = res;
load results\res_bo_low;   res_bo_low   = res;
load results\res_op_hgh;   res_op_hgh   = res;
load results\res_bo_hgh;   res_bo_hgh   = res;
load results\res_op_mu1;   res_op_mu1   = res;
load results\res_bo_mu1;   res_bo_mu1   = res;
clear res



COUNTRIES = 1:15;

for cty = COUNTRIES

    rop             = res_op(cty);
    rbo             = res_bo(cty);
    rol             = res_op_low(cty);
    rbl             = res_bo_low(cty);
    roh             = res_op_hgh(cty);
    rbh             = res_bo_hgh(cty);
    rom             = res_op_mu1(cty);
    rbm             = res_bo_mu1(cty);

    p               = rop.pop;

    Uop             = p.*bta.^(0:T-1)'.*U(rop.ca,rop.ci,rop.h,rop.eta);
    Ubo             = p.*bta.^(0:T-1)'.*U(rbo.ca,rbo.ci,rbo.h,rbo.eta);

    gmma            = 1/0.1;
    zeta            = 16500;
    Uol             = p.*bta.^(0:T-1)'.*U(rol.ca,rol.ci,rol.h,rol.eta);            
    Ubl             = p.*bta.^(0:T-1)'.*U(rbl.ca,rbl.ci,rbl.h,rbl.eta);        

    gmma            = 1/0.5;
    zeta            = 10.03;
    Uoh             = p.*bta.^(0:T-1)'.*U(roh.ca,roh.ci,roh.h,roh.eta);            
    Ubh             = p.*bta.^(0:T-1)'.*U(rbh.ca,rbh.ci,rbh.h,rbh.eta);        

    gmma=1/0.3;
    zeta=30;

    UopS            = sum(Uop)+bta*Uop(end)/(1-bta);
    UboS            = sum(Ubo)+bta*Ubo(end)/(1-bta);
    UolS            = sum(Uol)+bta*Uol(end)/(1-bta);
    UblS            = sum(Ubl)+bta*Ubl(end)/(1-bta);
    UohS            = sum(Uoh)+bta*Uoh(end)/(1-bta);
    UbhS            = sum(Ubh)+bta*Ubh(end)/(1-bta);

    welf(cty).wgbo  = (UboS/UopS)^(1/(1-mu))-1;          % Welfare gain if all balance relative to all optimizing
    welf(cty).wgbl  = (UblS/UolS)^(1/(1-mu))-1;         
    welf(cty).wgbh  = (UbhS/UohS)^(1/(1-mu))-1;         

    mu              = 1.0001; 
    muI             = mu;
    zeta            = 31.7;
    Uom             = p.*bta.^(0:T-1)'.*U(rom.ca,rom.ci,rom.h,rom.eta);
    Ubm             = p.*bta.^(0:T-1)'.*U(rbm.ca,rbm.ci,rbm.h,rbm.eta);
    UomS            = sum(Uom)+bta*Uom(end)/(1-bta);
    UbmS            = sum(Ubm)+bta*Ubm(end)/(1-bta);
    welf(cty).wgbm  = (UbmS/UomS)^(1/(1-mu))-1;     % Welfare gain of balancing relative to all optimizing, low mu
    mu              = 2; 
    muI             = mu;
    zeta            = 30;

    
    welf(cty).Uop   = Uop;
    welf(cty).Ubo   = Ubo;
    
end


cty_txt  = ['dk'; 'fi'; 'no'; 'sw'; 'uk'; 'be'; ...
           'fr'; 'de'; 'nl'; 'it'; 'po'; 'sp'; ...
           'ca'; 'us'; 'jp'];

fprintf(1,'Table 6: Welfare loss with balanced-budget policy\n');
fprintf(1,    'cy:       benchmark   gamma=0.1     gamma=0.5     mu=1\n')
for cty = [6 13 1 2 7 8 10 15 9 3 11 12 4 5 14]
    fprintf(1,'%2s:        %5.2f       %5.2f         %5.2f       %5.2f\n',cty_txt(cty,:),...
              -100*[welf(cty).wgbo welf(cty).wgbl welf(cty).wgbh welf(cty).wgbm])
end

